@@ -3,7 +3,7 @@ package TAP::Formatter::Session::TeamCity;
 use strict;
 use warnings;
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 use TAP::Parser::Result::Test;
 use TeamCity::Message qw( tc_message );
@@ -122,7 +122,7 @@ sub _handle_comment {
     # Always pass TC messages through immediately.
     if ( $comment =~ /^##teamcity\[/ ) {
         my $handle = $self->_tc_output_handle;
-        print {$handle} $comment, "\n" or die $!;
+        print STDOUT $comment, "\n" or die $!;
         return;
     }
 
